@@ -13,6 +13,8 @@ class TableNameNotFound(KeyError):
 class TableAlreadyExists(KeyError):
     """Table name already exists in the Metadata table"""
 
+class TableNotInMetadata(KeyError):
+    """Table does not exist in the Metadata table"""
 
 class IdsAlreadyExists(KeyError):
     """Annotation IDs already exists in the segmentation table"""
